function [ figs, figMax ] = plotKmerContribs( pos0, Contribs, maxContribs, opt );
% function [ figs, figMax ] = plotKmerContribs( pos0, Contribs, maxContribs );

% === init
alphabet = 'ACGT';
alphabetSize = length( alphabet );
% --- param

figs=[];
figMax=[];

if( ~exist('opt','var') )
  opt = [];
end;

if ~isfield(opt,'range')
  opt.range = 1:size(maxContribs,2);
end
handles=[];
lb=min(opt.range);
ub=max(opt.range);
maxContribs=maxContribs(:,lb:ub);

if ~isfield(opt,'titleStrContribs')
  opt.titleStrContribs = '';
end
if ~isfield(opt,'titleStrMaxContribs')
  opt.titleStrMaxContribs = '';
end
if ~isfield(opt,'plot_maxContrib')
  opt.plot_maxContrib = 1;
end
if ~isfield(opt,'plot_kmers')
  opt.plot_kmers = 1;
end
if ~isfield(opt,'orders')
  opt.orders = 1:size(maxContribs,1);
end
if ~isfield(opt, 'normalization')
	opt.normalization='none'
end
if ~isfield(opt, 'autoaspect')
	opt.autoaspect='1';
end
if ~isfield(opt,'bins')
  opt.bins = 64;
end
if ~isfield(opt,'interval')
  opt.interval = [min(maxContribs(:)), max(maxContribs(:))];
end

% --- prepare
[ kMax, seqLen ] = size( maxContribs );
pos = (1:seqLen) - pos0 + lb - 1;
if( seqLen <= 10 )
  tickDist = 2;
elseif( seqLen <= 50 )
  tickDist = 5;
else
  tickDist = 10;
end;
xTick = find( mod(pos,tickDist) == 0 );
xTickLabel = pos( xTick );

% === plot maximum contributions over k-mers
if opt.plot_maxContrib
  figMax = figure;
  set( gca, 'FontSize', 16 ); 

  if strcmp(opt.normalization,'quantile')
	  disp('using quantile normalization')
	  bins = opt.bins;
	  ints = sort(maxContribs(:))';
	  limits = [ints(round(linspace(1,length(ints),bins-1))) inf] ;
	  XT = zeros(size(maxContribs)) ;

	  for i = 1:length(limits)-1
		idx = find(maxContribs>=limits(i)&maxContribs<limits(i+1));
		XT(idx) = i;
	  end
  elseif strcmp(opt.normalization,'fixedinterval')
	  disp('using fixed interval normalization')
	  XT=maxContribs;
	  XT(XT<opt.interval(1))=opt.interval(1);
	  XT(XT>opt.interval(2))=opt.interval(2);
  elseif strcmp(opt.normalization,'scale')
	  disp('using scale -1,1 normalization')
	  XT=maxContribs;
	  XT=XT/max(abs(XT(:)));
  elseif strcmp(opt.normalization,'none')
	  disp('using no normalization')
	  XT=maxContribs;
  else
	  error('unknown normalization');
  end

  imagesc( flipud(XT) );

  title( opt.titleStrMaxContribs );
  ylabel( 'Motif Length (k)' );
  xlabel( 'Position' );
  set( gca, 'YTick', 1:kMax );
  set( gca, 'YTickLabel', kMax:-1:1 );
  set( gca, 'XTick', xTick );
  set( gca, 'XTickLabel', xTickLabel );
  if opt.autoaspect
	  p=get(gcf,'PaperPosition');
	  p(3)=8*size(XT,2)/50;
      p(3)=min(30,p(3));
	  set(gcf,'PaperPosition',p);
  end
  axis tight
end;

% === plot contributions for each k
if opt.plot_kmers
  for( k = opt.orders )
	assert(k<=kMax && k <= length(Contribs));
    figs = [figs figure];
    set( gca, 'FontSize', 16 );
	XT=Contribs{k}(:,lb:ub);
    imagesc(XT);
	title( sprintf('%s Order %d', opt.titleStrContribs, k) );
    xlabel( 'Position' );
    set( gca, 'XTick', xTick );
    set( gca, 'XTickLabel', xTickLabel );
    if( k == 1 )
      yTick = 1:alphabetSize;
      yTickLabel = cell( 1, alphabetSize );
      for( i = 1:alphabetSize )
        yTickLabel{i} = alphabet(i);
      end;
    else
      yTick = ((1:alphabetSize^2)-1) * alphabetSize^(k-2) + 1;
      yTickLabel = cell( 1, alphabetSize );
      a = repmat( alphabet(1), 1, k-2 );
      for( i = 1:(alphabetSize^2) )
        i1 = floor( (i-1) / alphabetSize ) + 1;
        i2 = mod( i-1, alphabetSize ) + 1;
        yTickLabel{i} = [ alphabet(i1) , alphabet(i2) , a ];
      end;
    end;
    set( gca, 'YTick', yTick );
    set( gca, 'YTickLabel', yTickLabel );
    if opt.autoaspect
        p=get(gcf,'PaperPosition');
        p(3)=8*size(XT,2)/50;
        p(3)=min(30,p(3));
        set(gcf,'PaperPosition',p);
    end
	axis tight
  end;
end
