function figs=plot_kmerdiversity( pos0, kmerdivs, opt );


figs=[];

if( ~exist('opt','var') )
  opt = [];
end;
if ~isfield(opt,'range')
  opt.range = 1:size(kmerdivs,2);
end
lb=min(opt.range);
ub=max(opt.range);
if ~isfield(opt,'titleStr')
  opt.titleStr = '';
end
if ~isfield(opt,'orders')
  opt.orders = 1:length(kmerdivs);
end
if ~isfield(opt, 'normalization')
	opt.normalization='none'
end
if ~isfield(opt,'bins')
  opt.bins = 64;
end
if ~isfield(opt, 'autoaspect')
	opt.autoaspect='1';
end

% --- prepare
seqLen=size( kmerdivs{1}-lb+1, 2 );
pos = (1:seqLen) - pos0 + lb - 1;
if( seqLen <= 10 )
  tickDist = 2;
elseif( seqLen <= 50 )
  tickDist = 5;
else
  tickDist = 10;
end;
xTick = find( mod(pos,tickDist) == 0 );
xTickLabel = pos( xTick );

for( k = opt.orders )
	w=kmerdivs{k}(:,lb:ub);
    figs = [figs figure];
	set( gca, 'FontSize', 16 ); 

	if strcmp(opt.normalization,'quantile')
	  disp('using quantile normalization')
	  bins = opt.bins;
	  ints = sort(w(:))';
	  limits = [ints(round(linspace(1,length(ints),bins-1))) inf] ;
	  XT = zeros(size(w)) ;

	  for i = 1:length(limits)-1
		idx = find(w>=limits(i)&w<limits(i+1));
		XT(idx) = i;
	  end
	elseif strcmp(opt.normalization,'fixedinterval')
	  disp('using fixed interval normalization')
	  XT=w;
	  XT(XT<opt.interval(1))=opt.interval(1);
	  XT(XT>opt.interval(2))=opt.interval(2);
	elseif strcmp(opt.normalization,'scale')
	  disp('using scale -1,1 normalization')
	  XT=w;
	  XT=XT/max(abs(XT(:)));
	elseif strcmp(opt.normalization,'none')
	  disp('using no normalization')
	  XT=w;
	else
	  error('unknown normalization');
	end

	imagesc( (XT) );

	title( sprintf('%s Order %d', opt.titleStr, k) );
	ylabel( 'Number of Motifs' );
	xlabel( 'Position' );
	l= get( gca, 'YTickLabel');
	set( gca, 'YTickLabel', l(end:-1:1,:));
	set( gca, 'XTick', xTick );
	set( gca, 'XTickLabel', xTickLabel );

    if opt.autoaspect
      p=get(gcf,'PaperPosition');
      p(3)=8*size(XT,2)/50;
      p(3)=min(30,p(3));
      set(gcf,'PaperPosition',p);
    end
end
axis tight
